### Praat Stimmprofil
# Joerg Mayer, jmayer@lingphon.net
# This is free software under the terms of the GNU General Public License 3
#
### Credits and References
# Paul Corthals, Ghent University, Belgium (extraction of voiced segments)
# Y. Maryn & D. Weenink (2015) Objective dysphonia measures in the program Praat: Smoothed Cepstral Peak Prominence and Acoustic Voice Quality Index. Journal of Voice, 29(1), 35-43.


### preparations
settingsFile$ = defaultDirectory$ + "/stimmprofil.settings"
settingsFile$ = replace$ (settingsFile$, "//", "/", 0)
recordingSpec$ = defaultDirectory$ + "/recording"
recordingSpec$ = replace$ (recordingSpec$, "//", "/", 0)
avqiSpec$ = defaultDirectory$ + "/avqi"
avqiSpec$ = replace$ (avqiSpec$, "//", "/", 0)
tempFile$ = defaultDirectory$ + "/stimmprofil"
tempFile$ = replace$ (tempFile$, "//", "/", 0)
if fileReadable (recordingSpec$)
	recording = readFile (recordingSpec$)
else
	exitScript: "Bitte zuerst ein neues Stimmprofil initialisieren: New > Stimmprofil" + newline$ + newline$
endif
if recording = 5
	exitScript: "Die maximale Anzahl an Sprachproben (4) ist erreicht." + newline$ + "Speichern Sie bei Bedarf das aktuelle Stimmprofil und intitialisieren Sie ein neues Profil für diese Sprachprobe." + newline$ + newline$
endif
thisTempFile$ = tempFile$ + string$ (recording)
nocheck deleteFile: thisTempFile$

### check sufficient selection length
# Move start of selection to nearest zero crossing
# Move end of selection to nearest zero crossing
len = Get selection length
if len < 0.07
	exitScript: "Die Auswahl ist zu klein! " + newline$ + "Sie haben ", len, " Sekunden ausgewählt." + newline$ + "Das erforderliche Minimum ist 0.07 Sekunden für alle Parameter außer Slope und Tilt. Für Slope und Tilt werden mindestens 0.8 Sekunden benötigt." + newline$ + newline$
endif

### check avqi status
if fileReadable (avqiSpec$)
	avqidata$ = readFile$ (avqiSpec$)
	avqistatus = extractNumber (avqidata$, "status:")
else
	avqistatus = 0
endif

if avqistatus = 0
	### prepare input form
	date$ = date$ ()
	day$ = mid$ (date$, 9, 2)
	year$ = mid$ (date$, 21, 4)
	month$ = mid$ (date$, 5, 3)
	if month$ = "Jan"
		month$ = "1"
	elsif month$ = "Feb"
		month$ = "2"
	elsif month$ = "Mar"
		month$ = "3"
	elsif month$ = "Apr"
		month$ = "4"
	elsif month$ = "May"
		month$ = "5"
	elsif month$ = "Jun"
		month$ = "6"
	elsif month$ = "Jul"
		month$ = "7"
	elsif month$ = "Aug"
		month$ = "8"
	elsif month$ = "Sep"
		month$ = "9"
	elsif month$ = "Oct"
		month$ = "10"
	elsif month$ = "Nov"
		month$ = "11"
	elsif month$ = "Dec"
		month$ = "12"
	endif
	aufnahmedatum$ = day$ + "." + month$ + "." + year$

	### input: specify recording
	beginPause: "Angaben zu Stimmprobe " + string$ (recording)
		comment: "Stimmprobe " + string$ (recording)
		sentence: "Aufnahmedatum", aufnahmedatum$
		choice: "Aufnahmetyp", 0
			option: "gehaltener Vokal (sv)"
			option: "Text (cs)"
		sentence: "Beschreibung", ""
		comment: "Acoustic Voice Quality Index (AVQI)"
		boolean: "AVQI berechnen", 0
		comment: "		Der AVQI basiert auf einer Vokal- und einer Textaufnahme,"
		comment: "		im nächsten Schritt müssen Sie daher den jeweils anderen"
		comment: "		Aufnahmetyp auswählen!"
		choice: "AVQI Version", 2
			option: "v02.02"
			option: "v03.01"
		comment: " "
		comment: "Analyse-Einstellungen"
		boolean: "Pitch range optimieren", 1
		boolean: "Advanced pitch settings optimieren", 0
	clicked = endPause: "Abbrechen", "OK", 2, 1
	if clicked = 1
		nocheck deleteFile: thisTempFile$
		exitScript ()
	endif

	if aVQI_berechnen = 1
		if aufnahmetyp = 1
			sellength = Get selection length
			if sellength >= 2.999999
				if sellength > 3
					surplus = sellength - 3
					Move start of selection by: surplus/2
					Move end of selection by: surplus/-2
				endif
				# Move start of selection to nearest zero crossing
				# Move end of selection to nearest zero crossing
				len = Get selection length
			else
				nocheck deleteFile: thisTempFile$
				exitScript: "Um den AVQI zuverlässig berechnen zu können," + newline$ + "wird ein mind. 3 Sek. langer Vokalabschnitt benötigt." + newline$ + "Bitte erweitern Sie die Auswahl." + newline$
			endif
		endif
		ex = Extract selected sound (windowed): "selection", "rectangular", 1, "no"
		endeditor
		numOfChannels = Get number of channels
		if numOfChannels > 1
			mono = Convert to mono
			filtered = noprogress Filter (stop Hann band): 0, 34, 0.1
			nocheck removeObject: mono
		else
			filtered = noprogress Filter (stop Hann band): 0, 34, 0.1
		endif
		Rename: "avqipart1"
		removeObject: ex
		nocheck writeFileLine: avqiSpec$, "status: ", 1
		nocheck appendFileLine: avqiSpec$, "versioni: ", aVQI_Version
		nocheck appendFileLine: avqiSpec$, "version: ", aVQI_Version$
		nocheck appendFileLine: avqiSpec$, "type: ", aufnahmetyp
		nocheck appendFileLine: avqiSpec$, "id: ", filtered
		nocheck appendFileLine: avqiSpec$, "desc: ", beschreibung$
		nocheck appendFileLine: avqiSpec$, "date: ", aufnahmedatum$
		nocheck appendFileLine: avqiSpec$, "optRange: ", pitch_range_optimieren
		nocheck appendFileLine: avqiSpec$, "optSettings: ", advanced_pitch_settings_optimieren
		# feedback
		if aufnahmetyp = 1
			avqi1type$ = "Vokal"
			avqi2type$ = "Text"
		else
			avqi1type$ = "Text"
			avqi2type$ = "Vokal"
		endif
		Select inner viewport: 0, 6, 0, 9
		Axes: 0, 6, 9, 0
		Black
		Paint rounded rectangle: "Yellow", 1, 5, 3, 6, 3
		Draw rounded rectangle: 1, 5, 3, 6, 3
		Text special: 1.5, "left", 3.5, "half", "Helvetica", 10, "0", "Der ausgewählte " + avqi1type$ + "-Abschnitt wurde registriert."
		Text special: 1.5, "left", 3.9, "half", "Helvetica", 10, "0", "Öffnen Sie nun eine " + avqi2type$ + "-Aufnahme, wählen Sie"
		Text special: 1.5, "left", 4.1, "half", "Helvetica", 10, "0", "einen geeigneten Abschnitt aus und klicken Sie:"
		Text special: 1.5, "left", 4.3, "half", "Helvetica", 10, "0", "##Pulses > Stimmprofil: Stimmprobe hinzufügen...#"
		if avqi1type$ = "Vokal" and aVQI_Version = 2
			Text special: 1.5, "left", 4.9, "half", "Helvetica", 10, "0", "##Text-Abschnitt: # (27 Silben / AVQI " + aVQI_Version$ + ")"
			Text special: 1.5, "left", 5.2, "half", "Helvetica", 10, "0", "%%Einst stritten sich Nordwind und Sonne,%"
			Text special: 1.5, "left", 5.4, "half", "Helvetica", 10, "0", "%%wer von ihnen beiden wohl der Stärkere wäre,%"
			Text special: 1.5, "left", 5.6, "half", "Helvetica", 10, "0", "%%als ein Wanderer%"
		elsif avqi1type$ = "Vokal" and aVQI_Version = 1
			Text special: 1.5, "left", 4.9, "half", "Helvetica", 10, "0", "##Text-Abschnitt: # (22 Silben / AVQI " + aVQI_Version$ + ")"
			Text special: 1.5, "left", 5.2, "half", "Helvetica", 10, "0", "%%Einst stritten sich Nordwind und Sonne,%"
			Text special: 1.5, "left", 5.4, "half", "Helvetica", 10, "0", "%%wer von ihnen beiden wohl der Stärkere wäre%"			
		else
			Text special: 1.5, "left", 5.2, "half", "Helvetica", 10, "0", "##Vokal: #min. 3 Sekunden"
		endif
		exitScript ()
	endif
else
	avqi1type = extractNumber (avqidata$, "type:")
	avqi1id = extractNumber (avqidata$, "id:")
	avqiversion = extractNumber (avqidata$, "versioni:")
	avqiversion$ = extractLine$ (avqidata$, "version: ")
	avqi1desc$ = extractLine$ (avqidata$, "desc: ")
	avqi1date$ = extractLine$ (avqidata$, "date: ")
	avqi1optRange = extractNumber (avqidata$, "optRange:")
	avqi1optSettings = extractNumber (avqidata$, "optSettings:")
	if avqi1type = 1
		avqi1type$ = "Vokal"
		avqi2type$ = "Text"
	else
		avqi1type$ = "Text"
		avqi2type$ = "Vokal"
		sellength = Get selection length
		if sellength >= 2.999999
			if sellength > 3
				surplus = sellength - 3
				Move start of selection by: surplus/2
				Move end of selection by: surplus/-2
			endif
			# Move start of selection to nearest zero crossing
			# Move end of selection to nearest zero crossing
			len = Get selection length
		else
			exitScript: "Um den AVQI zuverlässig berechnen zu können," + newline$ + "wird ein mind. 3 Sek. langer Vokalabschnitt benötigt." + newline$ + "Bitte erweitern Sie die Auswahl." + newline$
		endif
	endif
	aufnahmedatum$ = avqi1date$
	pitch_range_optimieren = avqi1optRange
	advanced_pitch_settings_optimieren = avqi1optSettings

	einzelergebnisse = 0
	### input: specify recording
	beginPause: "Angaben zu Stimmprobe " + string$ (recording) + " / Teil 2"
		comment: "Acoustic Voice Quality Index (AVQI)"
		comment: "	Im ersten Schritt hatten Sie eine " + avqi1type$ + "-Aufnahme ausgewählt,"
		comment: "	dies sollte daher eine " + avqi2type$ + "-Aufnahme sein."
		comment: "	Falls dies keine " + avqi2type$ + "-Aufnahme ist, können Sie die AVQI-Berechnung"
		comment: "	unten abbrechen."
		sentence: "Aufnahmedatum", aufnahmedatum$
		sentence: "Beschreibung", ""
		if recording <= 2
			comment: "Einzelergebnisse anzeigen (Vokal-, Text- und kombinierte Stimmprobe)"
			boolean: "Einzelergebnisse", 0
		else
			comment: "Mangels Platz für 3 Stimmproben, wird im Profil nur"
			comment: "das Ergebniss der kombinierten Stimmprobe angezeigt."
		endif
	clicked = endPause: "Abbrechen", "OK", 2, 1
	nocheck deleteFile: avqiSpec$
	if clicked = 1
		nocheck deleteFile: thisTempFile$
		removeObject: avqi1id
		exitScript ()
	endif
endif

### get user settings for pitch
i$ = Editor info
o_floor = extractNumber (i$, "Pitch floor:")
o_ceiling = extractNumber (i$, "Pitch ceiling:")
o_vthresh = extractNumber (i$, "Pitch voicing threshold:")
o_vcost = extractNumber (i$, "Pitch voiced/unvoiced cost:")

### extract selection and apply high-pass filter
ex = Extract selected sound (windowed): "selection", "rectangular", 1, "no"
endeditor
numOfChannels = Get number of channels
if numOfChannels > 1
	mono = Convert to mono
	s = noprogress Filter (stop Hann band): 0, 34, 0.1
	nocheck removeObject: mono
else
	s = noprogress Filter (stop Hann band): 0, 34, 0.1
endif


vlen_raw = len
tlen_raw = len
### if AVQI: prepare continuous speech sample for next step
if avqistatus = 1
	if avqi1type = 1
		vowelsample = avqi1id
		textsample = s
		selectObject: vowelsample
		vlen_raw = Get total duration
	else
		vowelsample = s
		textsample = avqi1id
	endif
	s = textsample
	aufnahmetyp = 2
endif

### continuous speech: extract and concatenate voiced segments
### largely based on a script by Paul Corthals, Ghent University, Belgium
if aufnahmetyp = 2
	# appendInfoLine: "continuous speech: extract and concatenate voiced segments"
	# appendInfoLine: "----------------------------------------"
	selectObject: s
	tlen_raw = Get total duration
	samplingRate = Get sampling frequency
	intermediateSamples = Get sampling period
	ov = Create Sound: "ov", 0, 0.001, samplingRate, "0"
	uniqname$ = replace_regex$ (date$ (), "[ :]", "", 0)
	selectObject: s
	tg = To TextGrid (silences): 50, 0.003, -25, 0.1, 0.1, "", uniqname$
	plusObject: s
	Extract non-empty intervals: 1, "no"
	conc = Concatenate
	removeObject: tg, s
	# remove extracted segments
	j = 0
	select all
	nos = numberOfSelected ()
	for i to nos
		fullName$ = selected$ (i)
		name$ = extractLine$ (fullName$, " ")
		if name$ = uniqname$
			j = j + 1
			remids [j] = selected (i)
		endif
	endfor
	for i to j
		removeObject: remids [i]
	endfor
	selectObject: conc
	signalEnd = Get end time
	windowBorderLeft = Get start time
	windowWidth = 0.03
	windowBorderRight = windowBorderLeft + windowWidth
	extremeRight = signalEnd - windowWidth
	globalPower = Get power in air
	voicelessThreshold = globalPower*(30/100)
	while windowBorderRight < extremeRight
		selectObject: conc
		part = Extract part: windowBorderLeft, windowBorderRight, "Rectangular", 1.0, "no"
		partialPower = Get power in air
		if partialPower > voicelessThreshold
			@checkZeros: part, 0, intermediateSamples
			if (checkZeros.zeroCrossingRate <> undefined) and (checkZeros.zeroCrossingRate < 3000)
				selectObject: ov, part
				oldov = ov
				ov = Concatenate
				removeObject: oldov
			endif
		endif
		removeObject: part
		windowBorderLeft = windowBorderLeft + 0.03
		windowBorderRight = windowBorderLeft + 0.03
	endwhile
	removeObject: conc
	s = ov
	selectObject: s
	tlen_sth = Get total duration
endif

procedure checkZeros: .sndid, .zeroCrossingRate, .isam
	selectObject: .sndid
	.start = 0.0025
	.startZero = Get nearest zero crossing: .start
	.findStart = .startZero
	.findStartZeroPlusOne = .startZero + .isam
	.startZeroPlusOne = Get nearest zero crossing: .findStartZeroPlusOne
	.zeroCrossings = 0
	.strips = 0
	while (.findStart < 0.0275) and (.findStart <> undefined)
		while .startZeroPlusOne = .findStart
			.findStartZeroPlusOne = .findStartZeroPlusOne + .isam
			.startZeroPlusOne = Get nearest zero crossing: .findStartZeroPlusOne
		endwhile
		.afstand = .startZeroPlusOne - .startZero
		.strips = .strips + 1
		.zeroCrossings = .zeroCrossings + 1
		.findStart = .startZeroPlusOne
	endwhile
	.zeroCrossingRate = .zeroCrossings/.afstand
endproc
### done with extraction and concatenation of voiced segments




### analyze at least once for simple voice intermediateSamples
### analyze at most 3 times for AVQI voice samples (vowel/text/combined)
loop = 0
repeat

	if avqistatus <> 1
		loop = 0
	elsif avqistatus = 1 and einzelergebnisse = 0
		loop = 0
		### concatenate vowel and continuous speech sample
		selectObject: s, vowelsample
		s = Concatenate
		aufnahmetyp = 3
	elsif avqistatus = 1 and einzelergebnisse = 1
		loop = loop + 1
		if loop = 1
			# loop = 1: analyze and draw vowel sample
			textsample = s
			s = vowelsample
			aufnahmetyp = 1
		elsif loop = 2
			# loop = 2: analyze and draw text sample
			vowelsample = s
			s = textsample
			aufnahmetyp = 2
			recording = recording + 1
		elsif loop = 3
			# loop = 3: analyze and draw combined sample
			selectObject: s, vowelsample
			s = Concatenate
			aufnahmetyp = 3
			recording = recording + 1
			loop = 0
		endif
	endif

	writeFile: recordingSpec$, recording
	thisTempFile$ = tempFile$ + string$ (recording)
	nocheck deleteFile: thisTempFile$

	### initialize feedback
	# appendInfoLine: "Parameter werden berechnet, bitte warten."

	### option: optimize pitch settings
	floor = o_floor
	ceiling = o_ceiling
	if pitch_range_optimieren = 1
		# appendInfoLine: "	optimize pitch range"
		# estimate pitch range (cf. Hirst, 2011)
		selectObject: s
		p = noprogress To Pitch: 0.01, 50, 700
		q1 = Get quantile: 0, 0, 0.25, "Hertz"
		q3 = Get quantile: 0, 0, 0.75, "Hertz"
		removeObject: p
		if q1 <> undefined and q3 <> undefined
			floor = round (q1*0.75)
			if floor < 60
				floor = 60
			endif
			ceiling = round (q3*2.5)
		endif
	endif
	vthresh = o_vthresh
	vcost = o_vcost
	if advanced_pitch_settings_optimieren = 1
		vthresh = 0.6
		vcost = 0.3
	endif


	### get parameters
	# cpps
	# appendInfoLine: "	smoothed cepstral peak prominence"
	selectObject: s
	tmplen = Get total duration
	# c = To PowerCepstrogram: floor, 0.002, 5000, 50
	# cpps = Get CPPS: "no", 0.01, 0.001, floor, ceiling, 0.05, "Parabolic", 0.001, 0, "Straight", "Robust"
	c = To PowerCepstrogram: 60, 0.002, 5000, 50
	cpps = Get CPPS: "no", 0.01, 0.001, 60, 330, 0.05, "Parabolic", 0.001, 0, "Straight", "Robust"

	# slope & tilt
	# appendInfoLine: "	spectral parameters"
	if tmplen >= 0.8
		selectObject: s
		l0 = noprogress To Ltas: 1
		slope = Get slope: 0, 1000, 1000, 10000, "energy"
		trendID = noprogress Compute trend line: 1, 10000
		tilt = Get slope: 0, 1000, 1000, 10000, "energy"
	elsif tmplen >= 0.07
		selectObject: s
		l0 = noprogress To Ltas: 12
		slope = Get slope: 0, 1000, 1000, 10000, "energy"
		trendID = noprogress Compute trend line: 1, 10000
		tilt = Get slope: 0, 1000, 1000, 10000, "energy"
	else
		slope = undefined
		tilt = undefined
	endif

	# H1-H2
	selectObject: s
	p2 = noprogress To Pitch (cc): 0, floor, 15, "no", 0.03, vthresh, 0.01, 0.35, vcost, ceiling
	selectObject: s,p2
	pp = noprogress To PointProcess (cc)
	n = Get number of points
	if n > 0
		selectObject: s,pp
		l1 = noprogress To Ltas (only harmonics): 20, 0.0001, 0.02, 1.3
		h1 = Get value in bin: 2
		h2 = Get value in bin: 3
		h1h2 = h1 - h2
	else
		h1h2 = undefined
		cpps = undefined
	endif

	# generate voice report
	selectObject: s,p2,pp
	voiceReport$ = Voice report: 0, 0, floor, ceiling, 1.3, 1.6, 0.03, vthresh

	# perturbation
	# appendInfoLine: "	perturbation"
	if n > 0
		jl = extractNumber (voiceReport$, "Jitter (local):")
		sl = extractNumber (voiceReport$, "Shimmer (local):")
		shimmerdB = extractNumber (voiceReport$, "Shimmer (local, dB):")
		jitterLoc = jl * 100
		shimmerLoc = sl * 100
	else
		jitterLoc = undefined
		shimmerLoc = undefined
		shimmerdB = undefined
	endif

	# HNR
	# appendInfoLine: "	harmonics-to-noise ratio"
	meanHNR = extractNumber (voiceReport$, "Mean harmonics-to-noise ratio:")

	# voice breaks
	vb = extractNumber (voiceReport$, "Degree of voice breaks:")
	voiceBreaks = vb * 100

	# pitch
	# appendInfoLine: "	pitch"
	selectObject: s
	p3 = noprogress To Pitch (ac): 0, floor, 15, "no", 0.03, vthresh, 0.01, 0.35, vcost, ceiling
	selectObject: s,p3
	pp2 = noprogress To PointProcess (cc)
	selectObject: s,p3,pp2
	voiceReport$ = Voice report: 0, 0, floor, ceiling, 1.3, 1.6, 0.03, vthresh
	sdPitch = extractNumber (voiceReport$, "Standard deviation:")
	meanPitch = extractNumber (voiceReport$, "Mean pitch:")
	minimumPitch = extractNumber (voiceReport$, "Minimum pitch:")
	maximumPitch = extractNumber (voiceReport$, "Maximum pitch:")
	semitones = (12/ln(2)) * ln(maximumPitch/minimumPitch)

	# AVQI
	if avqistatus = 1 and tmplen >= 0.8 and loop = 0
		if avqiversion = 2
			### AVQI v03.01 (Barsties & Maryn, 2015;  Barsties et al., 2018/in press)
			avqi = (4.152 - (0.177*cpps) - (0.006*meanHNR) - (0.037*shimmerLoc) + (0.941*shimmerdB) + (0.01*slope) + (0.093*tilt)) * 2.8902
		elsif avqiversion = 1
			### AVQI v02.02 (Maryn & Weenink, 2015)
			avqi = 9.072-0.245*cpps-0.161*meanHNR-0.470*shimmerLoc+6.158*shimmerdB-0.071*slope+0.170*tilt
			### AVQI v02.03 (https://www.vvl.be/documenten-en-paginas/praat-script-avqi-v0203)
			# avqi = ((3.295-(0.111*cpps)-(0.073*meanHNR)-(0.213*shimmerLoc)+(2.789*shimmerdB)-(0.032*slope)+(0.077*tilt))*2.208)+1.797
		endif
	else
		avqi = undefined
	endif

	### clean up analyses
	nocheck removeObject: c
	nocheck removeObject: l0
	nocheck removeObject: trendID
	nocheck removeObject: p2
	nocheck removeObject: p3
	nocheck removeObject: pp
	nocheck removeObject: pp2
	nocheck removeObject: l1
	# nocheck removeObject: t
	# nocheck removeObject: l2

	### save results
	nocheck appendFileLine: thisTempFile$, "recording: ", recording
	nocheck appendFileLine: thisTempFile$, "aufnahmedatum: ", aufnahmedatum$
	nocheck appendFileLine: thisTempFile$, "aufnahmetyp: ", aufnahmetyp
	nocheck appendFileLine: thisTempFile$, "beschreibung: ", beschreibung$
	nocheck appendFileLine: thisTempFile$, "vlen_raw: ", vlen_raw
	nocheck appendFileLine: thisTempFile$, "tlen_raw: ", tlen_raw
	nocheck appendFileLine: thisTempFile$, "tlen_sth: ", tlen_sth
	nocheck appendFileLine: thisTempFile$, "h1h2: ", h1h2
	nocheck appendFileLine: thisTempFile$, "meanPitch: ", meanPitch
	nocheck appendFileLine: thisTempFile$, "sdPitch: ", sdPitch
	nocheck appendFileLine: thisTempFile$, "minimumPitch: ", minimumPitch
	nocheck appendFileLine: thisTempFile$, "maximumPitch: ", maximumPitch
	nocheck appendFileLine: thisTempFile$, "semitones: ", semitones
	nocheck appendFileLine: thisTempFile$, "jitterLoc: ", jitterLoc
	nocheck appendFileLine: thisTempFile$, "shimmerLoc: ", shimmerLoc
	nocheck appendFileLine: thisTempFile$, "shimmerdB: ", shimmerdB
	nocheck appendFileLine: thisTempFile$, "cpps: ", cpps
	nocheck appendFileLine: thisTempFile$, "slope: ", slope
	nocheck appendFileLine: thisTempFile$, "tilt: ", tilt
	nocheck appendFileLine: thisTempFile$, "meanHNR: ", meanHNR
	nocheck appendFileLine: thisTempFile$, "voiceBreaks: ", voiceBreaks
	if avqistatus = 1 and loop = 0
		nocheck appendFileLine: thisTempFile$, "avqi: ", avqi
		nocheck appendFileLine: thisTempFile$, "avqi1type: ", avqi1type
		nocheck appendFileLine: thisTempFile$, "avqi1desc: ", avqi1desc$
		nocheck appendFileLine: thisTempFile$, "avqi1date: ", avqi1date$
		nocheck appendFileLine: thisTempFile$, "avqiversion: ", avqiversion$
	endif


include stimmprofil_draw.praat
until loop = 0


### clean up sounds
nocheck removeObject: avqi1id
nocheck removeObject: ex
nocheck removeObject: s
nocheck removeObject: ov
nocheck removeObject: vowelsample
nocheck removeObject: textsample
nocheck removeObject: done



